# MigrationImportResource

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**package_feed_space_id** | **str** |  | [optional] 
**package_id** | **str** |  | [optional] 
**package_version** | **str** |  | [optional] 
**password** | **str** |  | [optional] 
**is_encrypted_package** | **bool** |  | [optional] 
**is_dry_run** | **bool** |  | [optional] 
**overwrite_existing** | **bool** |  | [optional] 
**delete_package_on_completion** | **bool** |  | [optional] 
**success_callback_uri** | **str** |  | [optional] 
**failure_callback_uri** | **str** |  | [optional] 
**task_id** | **str** |  | [optional] 
**last_modified_on** | **datetime** |  | [optional] 
**last_modified_by** | **str** |  | [optional] 
**links** | **dict(str, str)** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


